NtfsFileReference

Struct NtfsFileReference 

pub struct NtfsFileReference(/* private fields */);
Absolute reference to a File Record on the filesystem, composed out of a File Record Number and a Sequence Number.

Reference: https://flatcap.github.io/linux-ntfs/ntfs/concepts/file_reference.html

Implementations

Source

impl NtfsFileReference

pub fn file_record_number(&self) -> u64

Returns the 48-bit File Record Number.

This can be fed into Ntfs::file to create an NtfsFile object for the corresponding File Record (if you cannot use Self::to_file for some reason).

pub fn sequence_number(&self) -> u16

Returns the 16-bit sequence number of the File Record.

In a consistent file system, this number matches what NtfsFile::sequence_number returns.

pub fn to_file<'n, T>(&self, ntfs: &'n Ntfs, fs: &mut T) -> Result<NtfsFile<'n>>
where T: Read + Seek,

Returns an NtfsFile for the file referenced by this object.