pub struct NtfsFileReference(/* private fields */);Expand description
Absolute reference to a File Record on the filesystem, composed out of a File Record Number and a Sequence Number.
Reference: https://flatcap.github.io/linux-ntfs/ntfs/concepts/file_reference.html
Implementations
Sourceimpl NtfsFileReference
impl NtfsFileReference
Sourcepub fn file_record_number(&self) -> u64
pub fn file_record_number(&self) -> u64
Returns the 48-bit File Record Number.
This can be fed into Ntfs::file to create an NtfsFile object for the corresponding File Record
(if you cannot use Self::to_file for some reason).
Sourcepub fn sequence_number(&self) -> u16
pub fn sequence_number(&self) -> u16
Returns the 16-bit sequence number of the File Record.
In a consistent file system, this number matches what NtfsFile::sequence_number returns.